xpcs\_toolkit.simplemask.ui package
===================================

UI components for the SimpleMask mask editing window.

Submodules
----------

xpcs\_toolkit.simplemask.ui.simplemask\_ui module
-------------------------------------------------

.. automodule:: xpcsviewer.simplemask.ui.simplemask_ui
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: xpcsviewer.simplemask.ui
   :members:
   :undoc-members:
   :show-inheritance:
